pub struct PreparedPost { /* private fields */ }Expand description
One validated document, its approved assets, and its cached content identity.
Implementations
Sourceimpl PreparedPost
impl PreparedPost
pub fn view(&self) -> PreparedPostView<'_>
Sourcepub fn finalize_revision(
&self,
renderer: &PostRendererIdentity,
pre_injection_article: &[u8],
) -> PostRevisionDigest
pub fn finalize_revision( &self, renderer: &PostRendererIdentity, pre_injection_article: &[u8], ) -> PostRevisionDigest
Bind rendered bytes to the already validated source and asset identities.